config

package
v0.93.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 28, 2026 License: MIT Imports: 0 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bool added in v0.17.0

func Bool(b bool) *bool

Bool returns a pointer to a bool value. Needed because Go doesn't allow &true. Used for *bool config fields that distinguish "not set" (nil) from "explicitly false".

func BoolOrDefault added in v0.43.0

func BoolOrDefault(b *bool, defaultVal bool) bool

BoolOrDefault dereferences a *bool, returning defaultVal if nil. Used for *bool config fields to get the value or a default.

func String added in v0.43.0

func String(s string) *string

String returns a pointer to a string value. Used for *string config fields that distinguish "not set" (nil) from "explicitly set to empty string".

func StringOrDefault added in v0.43.0

func StringOrDefault(s *string, defaultVal string) string

StringOrDefault dereferences a *string, returning defaultVal if nil. Used for *string config fields to get the value or a default.

Types

This section is empty.

Jump to