Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Bool ¶ added in v0.17.0
Bool returns a pointer to a bool value. Needed because Go doesn't allow &true. Used for *bool config fields that distinguish "not set" (nil) from "explicitly false".
func BoolOrDefault ¶ added in v0.43.0
BoolOrDefault dereferences a *bool, returning defaultVal if nil. Used for *bool config fields to get the value or a default.
func String ¶ added in v0.43.0
String returns a pointer to a string value. Used for *string config fields that distinguish "not set" (nil) from "explicitly set to empty string".
func StringOrDefault ¶ added in v0.43.0
StringOrDefault dereferences a *string, returning defaultVal if nil. Used for *string config fields to get the value or a default.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.